==> depmap_1.12.0.tar.gz: depmap/inst/doc/depmap.R <==
## ----style, echo = FALSE, results = 'asis'------------------------------------
BiocStyle::markdown()

## ---- echo = FALSE------------------------------------------------------------
suppressPackageStartupMessages(library("dplyr"))

## ----install, eval=FALSE------------------------------------------------------
#  install.packages("BiocManager")
#  BiocManager::install("depmap")

## ----import_EH, message = FALSE-----------------------------------------------
library("depmap")
library("ExperimentHub")

## ----ehquery------------------------------------------------------------------
## create ExperimentHub query object
eh <- ExperimentHub()
query(eh, "depmap")

## ---- echo = FALSE------------------------------------------------------------
rnai <- eh[["EH2260"]]

## ---- eval = FALSE------------------------------------------------------------
#  rnai <- eh[["EH2260"]]

## -----------------------------------------------------------------------------
rnai

## -----------------------------------------------------------------------------
depmap::depmap_rnai()

## ---- echo = FALSE------------------------------------------------------------
rm(rnai)

## ---- echo = FALSE------------------------------------------------------------
crispr <- eh[["EH2261"]]

## ---- eval = FALSE------------------------------------------------------------
#  crispr <- eh[["EH2261"]]

## -----------------------------------------------------------------------------
crispr

## -----------------------------------------------------------------------------
depmap::depmap_crispr()

## ---- echo = FALSE------------------------------------------------------------
rm(crispr)

## ---- echo = FALSE------------------------------------------------------------
copyNumber <- eh[["EH2262"]]

## ---- eval = FALSE------------------------------------------------------------
#  copyNumber <- eh[["EH2262"]]

## -----------------------------------------------------------------------------
copyNumber

## -----------------------------------------------------------------------------
depmap::depmap_copyNumber()

## ---- echo = FALSE------------------------------------------------------------
rm(copyNumber)

## ---- echo = FALSE------------------------------------------------------------
RPPA <- eh[["EH2263"]]

## ---- eval = FALSE------------------------------------------------------------
#  RPPA <- eh[["EH2263"]]

## -----------------------------------------------------------------------------
RPPA

## -----------------------------------------------------------------------------
depmap::depmap_RPPA()

## ---- echo = FALSE------------------------------------------------------------
rm(RPPA)

## ---- echo = FALSE------------------------------------------------------------
TPM <- eh[["EH2264"]]

## ---- eval = FALSE------------------------------------------------------------
#  TPM <- eh[["EH2264"]]

## -----------------------------------------------------------------------------
TPM

## -----------------------------------------------------------------------------
depmap::depmap_TPM()

## ---- echo = FALSE------------------------------------------------------------
rm(TPM)

## ---- echo = FALSE------------------------------------------------------------
metadata <- eh[["EH2266"]]

## ---- eval = FALSE------------------------------------------------------------
#  metadata <- eh[["EH2266"]]

## -----------------------------------------------------------------------------
metadata

## -----------------------------------------------------------------------------
depmap::depmap_metadata()

## ---- echo = FALSE------------------------------------------------------------
rm(metadata)

## ---- echo = FALSE------------------------------------------------------------
mutationCalls <- eh[["EH2265"]]

## ---- eval = FALSE------------------------------------------------------------
#  mutationCalls <- eh[["EH2265"]]

## -----------------------------------------------------------------------------
mutationCalls

## -----------------------------------------------------------------------------
depmap::depmap_mutationCalls()

## ---- echo = FALSE------------------------------------------------------------
rm(mutationCalls)

## ---- echo = FALSE------------------------------------------------------------
drug_sensitivity <- eh[["EH3087"]]

## ---- eval = FALSE------------------------------------------------------------
#  drug_sensitivity <- eh[["EH3087"]]

## -----------------------------------------------------------------------------
drug_sensitivity

## -----------------------------------------------------------------------------
depmap::depmap_drug_sensitivity()

## ---- echo = FALSE------------------------------------------------------------
rm(drug_sensitivity)

## ---- echo = FALSE------------------------------------------------------------
proteomic <- eh[["EH3459"]]

## ---- eval = FALSE------------------------------------------------------------
#  proteomic <- eh[["EH3459"]]

## -----------------------------------------------------------------------------
proteomic

## -----------------------------------------------------------------------------
depmap::depmap_proteomic()

## ---- echo = FALSE------------------------------------------------------------
rm(proteomic)

## ----echo = FALSE-------------------------------------------------------------
sessionInfo()

==> depmap_1.16.0.tar.gz: depmap/inst/doc/depmap.R <==
## ----style, echo = FALSE, results = 'asis'------------------------------------
BiocStyle::markdown()

## ----echo = FALSE-------------------------------------------------------------
suppressPackageStartupMessages(library("dplyr"))

## ----install, eval=FALSE------------------------------------------------------
#  install.packages("BiocManager")
#  BiocManager::install("depmap")

## ----import_EH, message = FALSE-----------------------------------------------
library("depmap")
library("ExperimentHub")

## ----ehquery------------------------------------------------------------------
## create ExperimentHub query object
eh <- ExperimentHub()
query(eh, "depmap")

## ----echo = FALSE-------------------------------------------------------------
rnai <- eh[["EH2260"]]

## ----eval = FALSE-------------------------------------------------------------
#  rnai <- eh[["EH2260"]]

## -----------------------------------------------------------------------------
rnai

## -----------------------------------------------------------------------------
depmap::depmap_rnai()

## ----echo = FALSE-------------------------------------------------------------
rm(rnai)

## ----echo = FALSE-------------------------------------------------------------
crispr <- eh[["EH2261"]]

## ----eval = FALSE-------------------------------------------------------------
#  crispr <- eh[["EH2261"]]

## -----------------------------------------------------------------------------
crispr

## -----------------------------------------------------------------------------
depmap::depmap_crispr()

## ----echo = FALSE-------------------------------------------------------------
rm(crispr)

## ----echo = FALSE-------------------------------------------------------------
copyNumber <- eh[["EH2262"]]

## ----eval = FALSE-------------------------------------------------------------
#  copyNumber <- eh[["EH2262"]]

## -----------------------------------------------------------------------------
copyNumber

## -----------------------------------------------------------------------------
depmap::depmap_copyNumber()

## ----echo = FALSE-------------------------------------------------------------
rm(copyNumber)

## ----echo = FALSE-------------------------------------------------------------
RPPA <- eh[["EH2263"]]

## ----eval = FALSE-------------------------------------------------------------
#  RPPA <- eh[["EH2263"]]

## -----------------------------------------------------------------------------
RPPA

## -----------------------------------------------------------------------------
depmap::depmap_RPPA()

## ----echo = FALSE-------------------------------------------------------------
rm(RPPA)

## ----echo = FALSE-------------------------------------------------------------
TPM <- eh[["EH2264"]]

## ----eval = FALSE-------------------------------------------------------------
#  TPM <- eh[["EH2264"]]

## -----------------------------------------------------------------------------
TPM

## -----------------------------------------------------------------------------
depmap::depmap_TPM()

## ----echo = FALSE-------------------------------------------------------------
rm(TPM)

## ----echo = FALSE-------------------------------------------------------------
metadata <- eh[["EH2266"]]

## ----eval = FALSE-------------------------------------------------------------
#  metadata <- eh[["EH2266"]]

## -----------------------------------------------------------------------------
metadata

## -----------------------------------------------------------------------------
depmap::depmap_metadata()

## ----echo = FALSE-------------------------------------------------------------
rm(metadata)

## ----echo = FALSE-------------------------------------------------------------
mutationCalls <- eh[["EH2265"]]

## ----eval = FALSE-------------------------------------------------------------
#  mutationCalls <- eh[["EH2265"]]

## -----------------------------------------------------------------------------
mutationCalls

## -----------------------------------------------------------------------------
depmap::depmap_mutationCalls()

## ----echo = FALSE-------------------------------------------------------------
rm(mutationCalls)

## ----echo = FALSE-------------------------------------------------------------
drug_sensitivity <- eh[["EH3087"]]

## ----eval = FALSE-------------------------------------------------------------
#  drug_sensitivity <- eh[["EH3087"]]

## -----------------------------------------------------------------------------
drug_sensitivity

## -----------------------------------------------------------------------------
depmap::depmap_drug_sensitivity()

## ----echo = FALSE-------------------------------------------------------------
rm(drug_sensitivity)

## ----echo = FALSE-------------------------------------------------------------
proteomic <- eh[["EH3459"]]

## ----eval = FALSE-------------------------------------------------------------
#  proteomic <- eh[["EH3459"]]

## -----------------------------------------------------------------------------
proteomic

## -----------------------------------------------------------------------------
depmap::depmap_proteomic()

## ----echo = FALSE-------------------------------------------------------------
rm(proteomic)

## ----echo = FALSE-------------------------------------------------------------
sessionInfo()
